# Magia Flow

## Brief

Design flow integration and automation with Magia.

## Project Roadmap

TBD

## Installation

```bash
pip install magia-flow
```

## Examples

TBD

## Documentation

TBD

## Contributing

We also have a [Contribution Guideline](docs/CONTRIBUTING.md) and [Code of Conduct](docs/CODE_OF_CONDUCT.md).
Please take a look before you contribute.

In case you are interested in this project, contact me via:
https://github.com/khwong-c

## Reference

TBD
